Aggregator.App.index_query.DomainRecord — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Aggregator.App.index_query.DomainRecord

class Aggregator.App.index_query.DomainRecord(filename: 'str', url: 'str', offset: 'int', length: 'int', digest: 'str | None' = None, encoding: 'str | None' = None, timestamp: 'datetime' = datetime.datetime(2022, 11, 10, 21, 20, 56, 601358))
  __init__(filename: str, url: str, offset: int, length: int, digest: Optional[str] = None, encoding: Optional[str] = None, timestamp: datetime = datetime.datetime(2022, 11, 10, 21, 20, 56, 601358)) → None

  Methods

  `__init__`(filename, url, offset, length[, ...]) |

  Attributes

  `digest` |
  `encoding` |
  `timestamp` |
  `filename` |
  `url` |
  `offset` |
  `length` |